# Easy PIL
A library to make common tasks of Pillow easy.

# Usage
[Examples](https://github.com/shahriyardx/easy-pil/tree/master/examples)

[Tutorials](https://youtube.com/playlist?list=PLb_oBhGqAlbT4yVqV0TSXggA8b0lZhGhn)

# Changelog

## 0.0.1
- First working release

## 0.0.2
- Fix some bugs

## 0.0.3
- Added `multicolor_text` method

## 0.0.4
- Fix README

## 0.0.5
- Added `polygon` method

## 0.0.6
- Added `arc` and `rounded_bar` methods